Welcome to iced-x86's documentation!
====================================

.. toctree::
	src/BlockEncoder
	src/Decoder
	src/Encoder
	src/FastFormatter
	src/Formatter
	src/Instruction
	src/InstructionInfo
	src/InstructionInfoFactory
	src/OpCodeInfo
	:maxdepth: 2
	:caption: Classes:

.. toctree::
	src/ConstantOffsets
	src/FpuStackIncrementInfo
	src/MemoryOperand
	src/MemorySizeExt
	src/MemorySizeInfo
	src/RegisterExt
	src/RegisterInfo
	src/UsedMemory
	src/UsedRegister
	:maxdepth: 2
	:caption: Misc Classes:

.. toctree::
	src/CC_a
	src/CC_ae
	src/CC_b
	src/CC_be
	src/CC_e
	src/CC_g
	src/CC_ge
	src/CC_l
	src/CC_le
	src/CC_ne
	src/CC_np
	src/CC_p
	src/Code
	src/CodeSize
	src/ConditionCode
	src/CpuidFeature
	src/DecoderError
	src/DecoderOptions
	src/EncodingKind
	src/FlowControl
	src/FormatMnemonicOptions
	src/FormatterSyntax
	src/MandatoryPrefix
	src/MemorySize
	src/MemorySizeOptions
	src/Mnemonic
	src/OpAccess
	src/OpCodeOperandKind
	src/OpCodeTableKind
	src/OpKind
	src/Register
	src/RepPrefixKind
	src/RflagsBits
	src/RoundingControl
	src/TupleType
	:maxdepth: 2
	:caption: Enums:


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
